@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 from google.cloud.automl_v1.types import dataset as gca_dataset
@@ -63,8 +65,15 @@ class CreateDatasetRequest(proto.Message):
             Required. The dataset to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    dataset = proto.Field(proto.MESSAGE, number=2, message=gca_dataset.Dataset,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    dataset: gca_dataset.Dataset = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=gca_dataset.Dataset,
+    )
 
 
 class GetDatasetRequest(proto.Message):
@@ -77,7 +86,10 @@ class GetDatasetRequest(proto.Message):
             retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListDatasetsRequest(proto.Message):
@@ -110,10 +122,22 @@ class ListDatasetsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListDatasetsResponse(proto.Message):
@@ -121,7 +145,7 @@ class ListDatasetsResponse(proto.Message):
     [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
 
     Attributes:
-        datasets (Sequence[google.cloud.automl_v1.types.Dataset]):
+        datasets (MutableSequence[google.cloud.automl_v1.types.Dataset]):
             The datasets read.
         next_page_token (str):
             A token to retrieve next page of results. Pass to
@@ -133,10 +157,15 @@ class ListDatasetsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    datasets = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_dataset.Dataset,
+    datasets: MutableSequence[gca_dataset.Dataset] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_dataset.Dataset,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateDatasetRequest(proto.Message):
@@ -152,9 +181,15 @@ class UpdateDatasetRequest(proto.Message):
             resource.
     """
 
-    dataset = proto.Field(proto.MESSAGE, number=1, message=gca_dataset.Dataset,)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    dataset: gca_dataset.Dataset = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_dataset.Dataset,
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -168,7 +203,10 @@ class DeleteDatasetRequest(proto.Message):
             delete.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ImportDataRequest(proto.Message):
@@ -185,8 +223,15 @@ class ImportDataRequest(proto.Message):
             domain specific semantics, if any.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    input_config = proto.Field(proto.MESSAGE, number=3, message=io.InputConfig,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    input_config: io.InputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.InputConfig,
+    )
 
 
 class ExportDataRequest(proto.Message):
@@ -200,8 +245,15 @@ class ExportDataRequest(proto.Message):
             Required. The desired output location.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    output_config = proto.Field(proto.MESSAGE, number=3, message=io.OutputConfig,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_config: io.OutputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.OutputConfig,
+    )
 
 
 class GetAnnotationSpecRequest(proto.Message):
@@ -214,7 +266,10 @@ class GetAnnotationSpecRequest(proto.Message):
             spec to retrieve.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateModelRequest(proto.Message):
@@ -229,8 +284,15 @@ class CreateModelRequest(proto.Message):
             Required. The model to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    model = proto.Field(proto.MESSAGE, number=4, message=gca_model.Model,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    model: gca_model.Model = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=gca_model.Model,
+    )
 
 
 class GetModelRequest(proto.Message):
@@ -242,7 +304,10 @@ class GetModelRequest(proto.Message):
             Required. Resource name of the model.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListModelsRequest(proto.Message):
@@ -278,10 +343,22 @@ class ListModelsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListModelsResponse(proto.Message):
@@ -289,7 +366,7 @@ class ListModelsResponse(proto.Message):
     [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
 
     Attributes:
-        model (Sequence[google.cloud.automl_v1.types.Model]):
+        model (MutableSequence[google.cloud.automl_v1.types.Model]):
             List of models in the requested page.
         next_page_token (str):
             A token to retrieve next page of results. Pass to
@@ -301,8 +378,15 @@ class ListModelsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    model = proto.RepeatedField(proto.MESSAGE, number=1, message=gca_model.Model,)
-    next_page_token = proto.Field(proto.STRING, number=2,)
+    model: MutableSequence[gca_model.Model] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_model.Model,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class DeleteModelRequest(proto.Message):
@@ -315,7 +399,10 @@ class DeleteModelRequest(proto.Message):
             deleted.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UpdateModelRequest(proto.Message):
@@ -331,9 +418,15 @@ class UpdateModelRequest(proto.Message):
             resource.
     """
 
-    model = proto.Field(proto.MESSAGE, number=1, message=gca_model.Model,)
-    update_mask = proto.Field(
-        proto.MESSAGE, number=2, message=field_mask_pb2.FieldMask,
+    model: gca_model.Model = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message=gca_model.Model,
+    )
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=field_mask_pb2.FieldMask,
     )
 
 
@@ -364,19 +457,22 @@ class DeployModelRequest(proto.Message):
             deploy.
     """
 
-    image_object_detection_model_deployment_metadata = proto.Field(
+    image_object_detection_model_deployment_metadata: image.ImageObjectDetectionModelDeploymentMetadata = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="model_deployment_metadata",
         message=image.ImageObjectDetectionModelDeploymentMetadata,
     )
-    image_classification_model_deployment_metadata = proto.Field(
+    image_classification_model_deployment_metadata: image.ImageClassificationModelDeploymentMetadata = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="model_deployment_metadata",
         message=image.ImageClassificationModelDeploymentMetadata,
     )
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class UndeployModelRequest(proto.Message):
@@ -389,7 +485,10 @@ class UndeployModelRequest(proto.Message):
             undeploy.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ExportModelRequest(proto.Message):
@@ -407,9 +506,14 @@ class ExportModelRequest(proto.Message):
             configuration.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    output_config = proto.Field(
-        proto.MESSAGE, number=3, message=io.ModelExportOutputConfig,
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    output_config: io.ModelExportOutputConfig = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=io.ModelExportOutputConfig,
     )
 
 
@@ -423,7 +527,10 @@ class GetModelEvaluationRequest(proto.Message):
             evaluation.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class ListModelEvaluationsRequest(proto.Message):
@@ -460,10 +567,22 @@ class ListModelEvaluationsRequest(proto.Message):
             call.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    filter = proto.Field(proto.STRING, number=3,)
-    page_size = proto.Field(proto.INT32, number=4,)
-    page_token = proto.Field(proto.STRING, number=6,)
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    filter: str = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    page_size: int = proto.Field(
+        proto.INT32,
+        number=4,
+    )
+    page_token: str = proto.Field(
+        proto.STRING,
+        number=6,
+    )
 
 
 class ListModelEvaluationsResponse(proto.Message):
@@ -471,7 +590,7 @@ class ListModelEvaluationsResponse(proto.Message):
     [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
 
     Attributes:
-        model_evaluation (Sequence[google.cloud.automl_v1.types.ModelEvaluation]):
+        model_evaluation (MutableSequence[google.cloud.automl_v1.types.ModelEvaluation]):
             List of model evaluations in the requested
             page.
         next_page_token (str):
@@ -486,10 +605,17 @@ class ListModelEvaluationsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    model_evaluation = proto.RepeatedField(
-        proto.MESSAGE, number=1, message=gca_model_evaluation.ModelEvaluation,
+    model_evaluation: MutableSequence[
+        gca_model_evaluation.ModelEvaluation
+    ] = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message=gca_model_evaluation.ModelEvaluation,
+    )
+    next_page_token: str = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
