@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 
@@ -35,18 +37,15 @@ class VideoClassificationDatasetMetadata(proto.Message):
 
 
 class VideoObjectTrackingDatasetMetadata(proto.Message):
-    r"""Dataset metadata specific to video object tracking.
-    """
+    r"""Dataset metadata specific to video object tracking."""
 
 
 class VideoClassificationModelMetadata(proto.Message):
-    r"""Model metadata specific to video classification.
-    """
+    r"""Model metadata specific to video classification."""
 
 
 class VideoObjectTrackingModelMetadata(proto.Message):
-    r"""Model metadata specific to video object tracking.
-    """
+    r"""Model metadata specific to video object tracking."""
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
